@@ -1,14 +1,14 @@
-from dataclasses import dataclass
+from attrs import define
 from typing import Dict, Any
 
 
-@dataclass
+@define
 class FakeConfig:
     values: Dict[str, Any]
 
-    def __getattr__(self, name: str):
+    def __getattr__(self, name: str) -> Any:
         value = self.values[name]
         if isinstance(value, dict):
-            return FakeConfig(value)  # type: ignore
+            return FakeConfig(value)
         else:
             return value
